@@ -2,7 +2,7 @@
 /* vim:set et sts=4: */
 /* ibus - The Input Bus
  * Copyright (C) 2008-2015 Peng Huang <shawn.p.huang@gmail.com>
- * Copyright (C) 2015-2019 Takao Fujiwara <takao.fujiwara1@gmail.com>
+ * Copyright (C) 2015-2024 Takao Fujiwara <takao.fujiwara1@gmail.com>
  * Copyright (C) 2008-2017 Red Hat, Inc.
  *
  * This library is free software; you can redistribute it and/or
@@ -95,23 +95,27 @@ struct _IBusEngineSimpleClass {
     gpointer pdummy[8];
 };
 
+/* common with invalid_accelerator_vals[]. */
 static const guint16 IBUS_COMPOSE_IGNORE_KEYLIST[] = {
-    IBUS_KEY_Shift_L,
-    IBUS_KEY_Shift_R,
-    IBUS_KEY_Control_L,
-    IBUS_KEY_Control_R,
-    IBUS_KEY_Caps_Lock,
-    IBUS_KEY_Shift_Lock,
-    IBUS_KEY_Meta_L,
-    IBUS_KEY_Meta_R,
-    IBUS_KEY_Alt_L,
-    IBUS_KEY_Alt_R,
-    IBUS_KEY_Super_L,
-    IBUS_KEY_Super_R,
-    IBUS_KEY_Hyper_L,
-    IBUS_KEY_Hyper_R,
-    IBUS_KEY_Mode_switch,
-    IBUS_KEY_ISO_Level3_Shift
+    IBUS_KEY_Shift_L, IBUS_KEY_Shift_R,
+    IBUS_KEY_Control_L, IBUS_KEY_Control_R,
+    IBUS_KEY_Caps_Lock, IBUS_KEY_Shift_Lock, IBUS_KEY_ISO_Lock,
+    IBUS_KEY_Meta_L, IBUS_KEY_Meta_R,
+    IBUS_KEY_Alt_L, IBUS_KEY_Alt_R,
+    IBUS_KEY_Super_L, IBUS_KEY_Super_R,
+    IBUS_KEY_Hyper_L, IBUS_KEY_Hyper_R,
+    IBUS_KEY_ISO_Level2_Latch,
+    IBUS_KEY_ISO_Level3_Latch, IBUS_KEY_ISO_Level3_Lock,
+    IBUS_KEY_ISO_Level3_Shift,
+    IBUS_KEY_ISO_Level5_Latch, IBUS_KEY_ISO_Level5_Lock,
+    IBUS_KEY_ISO_Level5_Shift,
+    IBUS_KEY_ISO_Group_Latch, IBUS_KEY_ISO_Group_Lock,
+    IBUS_KEY_ISO_Group_Shift,
+    IBUS_KEY_ISO_Next_Group, IBUS_KEY_ISO_Next_Group_Lock,
+    IBUS_KEY_ISO_Prev_Group, IBUS_KEY_ISO_Prev_Group_Lock,
+    IBUS_KEY_ISO_First_Group, IBUS_KEY_ISO_First_Group_Lock,
+    IBUS_KEY_ISO_Last_Group, IBUS_KEY_ISO_Last_Group_Lock,
+    IBUS_KEY_Overlay1_Enable, IBUS_KEY_Overlay2_Enable
 };
 
 GType   ibus_engine_simple_get_type       (void);
