@@ -2,8 +2,8 @@
 /* vim:set et sts=4: */
 /* ibus - The Input Bus
  * Copyright (C) 2008-2013 Peng Huang <shawn.p.huang@gmail.com>
- * Copyright (C) 2018-2023 Takao Fujiwara <takao.fujiwara1@gmail.com>
- * Copyright (C) 2008-2018 Red Hat, Inc.
+ * Copyright (C) 2018-2025 Takao Fujiwara <takao.fujiwara1@gmail.com>
+ * Copyright (C) 2008-2025 Red Hat, Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -551,5 +551,25 @@ void         ibus_input_context_set_post_process_key_event
 void         ibus_input_context_post_process_key_event
                                             (IBusInputContext   *context);
 
+/**
+ * ibus_input_context_set_preedit_format:
+ * @context: An #IBusInputContext.
+ * @format: An #IBusPreeditFormat.
+ *
+ * The pre-edit attributes follows the format and the default is
+ * #IBUS_PREEDIT_FORMAT_RGBA and the types of all #IBusAttribute are should be
+ * one of  #IBUS_ATTR_TYPE_UNDERLINE, #IBUS_ATTR_TYPE_FOREGROUND,
+ * #IBUS_ATTR_TYPE_BACKGROUND.
+ * In case that the format is #IBUS_PREEDIT_FORMAT_HINT, the types of all
+ * #IBusAttribute are #IBUS_ATTR_TYPE_HINT.
+ *
+ * See also ibus_text_get_attributes();
+ *
+ * Since: 1.5.33
+ * Stability: Unstable
+ */
+void         ibus_input_context_set_preedit_format
+                                            (IBusInputContext   *context,
+                                             IBusPreeditFormat   format);
 G_END_DECLS
 #endif
