@@ -1,8 +1,9 @@
 /* -*- mode: C; c-basic-offset: 4; indent-tabs-mode: nil; -*- */
 /* vim:set et sts=4: */
 /* ibus - The Input Bus
- * Copyright (C) 2008-2013 Peng Huang <shawn.p.huang@gmail.com>
- * Copyright (C) 2008-2013 Red Hat, Inc.
+ * Copyright (C) 2008-2015 Peng Huang <shawn.p.huang@gmail.com>
+ * Copyright (C) 2011-2023 Takao Fujiwara <takao.fujiwara1@gmail.com>
+ * Copyright (C) 2008-2015 Red Hat, Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -79,6 +80,20 @@ struct _IBusServiceClass {
 
     /*< public >*/
     /* virtual functions */
+    /**
+     * IBusServiceClass::service_method_call:
+     * @service: An #IBusService.
+     * @connection: A dbus connection.
+     * @sender: A sender.
+     * @object_path: An object path.
+     * @interface_name: An interface name.
+     * @method_name: A method name.
+     * @parameters: A parameters.
+     * @invocation: A dbus method invocation.
+     *
+     * The ::service_method_call class method is to connect
+     * GDBusInterfaceMethodCallFunc().
+     */
     void        (* service_method_call)
                                     (IBusService        *service,
                                      GDBusConnection    *connection,
@@ -89,6 +104,21 @@ struct _IBusServiceClass {
                                      GVariant           *parameters,
                                      GDBusMethodInvocation
                                                         *invocation);
+    /**
+     * IBusServiceClass::service_get_property:
+     * @service: An #IBusService.
+     * @connection: A dbus connection.
+     * @sender: A sender.
+     * @object_path: An object path.
+     * @interface_name: An interface name.
+     * @property_name: A property name.
+     * @error: Return location for error or %NULL.
+     *
+     * The ::service_get_property class method is to connect
+     * GDBusInterfaceGetPropertyFunc().
+     *
+     * Returns: (nullable) (transfer full): A variant.
+     */
     GVariant *  (* service_get_property)
                                     (IBusService        *service,
                                      GDBusConnection    *connection,
@@ -97,6 +127,22 @@ struct _IBusServiceClass {
                                      const gchar        *interface_name,
                                      const gchar        *property_name,
                                      GError            **error);
+    /**
+     * IBusServiceClass::service_set_property:
+     * @service: An #IBusService.
+     * @connection: A dbus connection.
+     * @sender: A sender.
+     * @object_path: An object path.
+     * @interface_name: An interface name.
+     * @property_name: An property name.
+     * @value: An property value.
+     * @error: Return location for error or %NULL.
+     *
+     * The ::service_set_property class method is to connect
+     * GDBusInterfaceSetPropertyFunc().
+     *
+     * Returns: %TRUE if set the value else %FALSE.
+     */
     gboolean    (* service_set_property)
                                     (IBusService        *service,
                                      GDBusConnection    *connection,
@@ -118,28 +164,32 @@ GType            ibus_service_get_type          (void);
 
 /**
  * ibus_service_new:
+ * @connection: A GDBusConnection.
  * @path: Object path.
- * @returns: A newly allocated IBusService
  *
- * New an IBusService.
+ * Creantes a new #IBusService.
+ *
+ * Returns: A newly allocated #IBusService
  */
 IBusService     *ibus_service_new               (GDBusConnection    *connection,
                                                  const gchar        *path);
 /**
  * ibus_service_get_object_path:
  * @service: An IBusService.
- * @returns: The object path of @service
  *
- * Returns the object path of an IBusService.
+ * Gets the object path of an IBusService.
+ *
+ * Returns: The object path of @service
  */
 const gchar     *ibus_service_get_object_path   (IBusService        *service);
 
 /**
  * ibus_service_get_connection:
  * @service: An IBusService.
- * @returns: (transfer none): A #GDBusConnection of an #IBusService instance.
  *
- * Returns a connections.
+ * Gets a connections.
+ *
+ * Returns: (transfer none): A #GDBusConnection of an #IBusService instance.
  */
 GDBusConnection *ibus_service_get_connection    (IBusService        *service);
 
@@ -148,9 +198,10 @@ GDBusConnection *ibus_service_get_connection    (IBusService        *service);
  * @service: An IBusService.
  * @connection: A GDBusConnection the service will be registered to.
  * @error: Return location for error or NULL.
- * @returns: TRUE if the service was registered, FALSE otherwise.
  *
  * Registers service to a connection.
+ *
+ * Returns: %TRUE if the service was registered, %FALSE otherwise.
  */
 gboolean         ibus_service_register          (IBusService        *service,
                                                  GDBusConnection    *connection,
@@ -174,9 +225,10 @@ void             ibus_service_unregister        (IBusService        *service,
  * @name: Name of the signal.
  * @first_arg_type: Type of first argument.
  * @...: Rest of arguments, NULL to mark the end.
- * @returns: TRUE if succeed; FALSE otherwise.
  *
- * Send signal to all the IBusConnections of an IBusService.
+ * Sends signal to all the #IBusConnections of an #IBusService.
+ *
+ * Returns: %TRUE if succeed; %FALSE otherwise.
  *
  * see_also: g_dbus_connection_emit_signal()
  */
@@ -192,11 +244,30 @@ gboolean         ibus_service_emit_signal       (IBusService        *service,
  * @xml_data: The introspection xml data.
  *
  * Set the interface introspection information with the service class.
+ *
+ * Returns: %TRUE if @xml_data is valid and succeeded to be added;
+ *          %FALSE otherwise.
  */
 gboolean         ibus_service_class_add_interfaces
                                                 (IBusServiceClass   *klass,
                                                  const gchar        *xml_data);
 
+/**
+ * ibus_service_class_free_interfaces:
+ * @klass: An IBusServiceClass.
+ * @depth: The number of D-Bus introspection interfaces.
+ *
+ * Free the first @depth interfaces if @depth is positive. Free the last
+ * -@depth interfaces if @depth is negative.
+ *
+ * Returns: The actual freed number of the introspection interfaces
+ * if @depth is not 0.
+ * If @depth is 0, the total number of the introspection interfaces is
+ * returned but any interfaces are not freed.
+ */
+int              ibus_service_class_free_interfaces
+                                                (IBusServiceClass   *klass,
+                                                 int                 depth);
 
 G_END_DECLS
 #endif
